@@ -53,7 +53,7 @@ function Download_Anime
   [[ ${2//-/} = 'Describe' ]] &&
   {
     tr -cd '\11\12\15\40-\176' < $File > clean-file; rm $File; mv clean-file $File
-    img_url=$(grep 'image_src' $File | gawk -F"<" '{ print $2}' | sed 's_.*href=.\(.*\)".*_\1_')
+    img_url=$(grep 'og:image' $File | sed 's,.*content=.\([^ ]*\).[ ].*,\1,')
     ext=$(sed 's_.*\.\(.*$\)_\1_' <<< $img_url)
     img_file=preview_pic.$ext
 
