@@ -95,7 +95,11 @@ MANGA-PROCEDURE
     [[ ! -f $episode_file ]] && episode_file=$(ls ${episode_file}* 2> /dev/null)
 
     # Discover whether we can parse the video links with free software; provide as much detail as possible
+    unset selected_domain python_domain
     Extract_Information $episode_file
+    if [[ -z ${selected_domain:-} && -z ${python_domain:-} ]]
+    then Whats_Missing $6 ${episode_name[$j]}; return
+    fi
   fi
   # Download the actual gallery page
   if [[ $option = $DOMAIN1 ]]; then :
@@ -126,14 +130,19 @@ MANGA-PROCEDURE
       # The web-page is serving DUAL episodes (2 on one page)
       {
         for j in {0..1}; do
-          server_path[$j]=$(grep "${python_domain:-file}" $episode_file | $([[ -n ${selected_domain:-} ]] && echo "grep $selected_domain" ||
-                            echo "grep '.*'") | sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' $([[ -n $python_domain ]] &&
-                            echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE | grep 'embed_jw' | grep -v 'itemprop' | sed -n "`expr $j '+' 1`  s/.*/&/p")
+          # Extract the episode address on the server
+          server_path[$j]=$(egrep "${python_domain:-file}|${selected_domain:-}" $episode_file   |\
+                            sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' \
+                            $([[ -n $python_domain ]] && echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE |\
+                            grep 'embed_js' | grep -v 'itemprop' | egrep 'file|embed' |\
+                            sed -n "`expr $j '+' 1` p" | sed 's/%26videoAutoPlay=0//')
 
-          [[ -z ${server_path[$j]} ]] &&
-          server_path[$j]=$(grep "${python_domain:-file}" $episode_file | $([[ -n ${selected_domain:-} ]] && echo "grep $selected_domain" ||
-                            echo "grep '.*'") | sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' $([[ -n $python_domain ]] &&
-                            echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE | grep -v 'embed_jw' | grep -v 'itemprop' | sed -n "`expr $j '+' 1`  s/.*/&/p")
+          [[ -z ${server_path[$j]:-} ]] &&
+          server_path[$j]=$(egrep "${python_domain:-file}|${selected_domain:-}" $episode_file   |\
+                            sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' \
+                            $([[ -n $python_domain ]] && echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE |\
+                            egrep -v 'embed_js|itemprop' | egrep 'file|embed' |\
+                            sed -n "`expr $j '+' 1` p" | sed 's/%26videoAutoPlay=0//')
 
           # This is rare, but sometimes a dual episode web-link, may have both episodes combined inside a single video. |
           # The assumption here is that it would be weird to have only 1 video on a DUAL video web-page.                |
@@ -173,14 +182,18 @@ MANGA-PROCEDURE
             episode_name[$j]=${episode_title}${episode_number}
 
             # Extract the episode address on the server
-            server_path[$j]=$(grep "${python_domain:-file}" $episode_file | $([[ -n ${selected_domain:-} ]] && echo "grep $selected_domain" ||
-                              echo "grep '.*'") | sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' $([[ -n $python_domain ]] &&
-                              echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE | grep 'embed_jw' | grep -v 'itemprop' | sed -n "`expr $j '+' 1`  s/.*/&/p")
+            server_path[$j]=$(egrep "${python_domain:-file}|${selected_domain:-}" $episode_file   |\
+                              sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' \
+                              $([[ -n $python_domain ]] && echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE |\
+                              grep 'embed_js' | grep -v 'itemprop' | egrep 'file|embed' |\
+                              sed -n "`expr $j '+' 1` p" | sed 's/%26videoAutoPlay=0//')
 
             [[ -z ${server_path[$j]:-} ]] &&
-            server_path[$j]=$(grep "${python_domain:-file}" $episode_file | $([[ -n ${selected_domain:-} ]] && echo "grep $selected_domain" ||
-                              echo "grep '.*'") | sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' $([[ -n $python_domain ]] &&
-                              echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE | grep -v 'embed_jw' | grep -v 'itemprop' | sed -n "`expr $j '+' 1`  s/.*/&/p")
+            server_path[$j]=$(egrep "${python_domain:-file}|${selected_domain:-}" $episode_file   |\
+                              sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' \
+                              $([[ -n $python_domain ]] && echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE |\
+                              egrep -v 'embed_js|itemprop' | egrep 'file|embed' |\
+                              sed -n "`expr $j '+' 1` p" | sed 's/%26videoAutoPlay=0//')
         done
       }
       # Begin processing every episode on the webpage
@@ -216,9 +229,10 @@ MANGA-PROCEDURE
     # The web-page is serving only one episode
     {
       # Determine the server path to the video, and if we can't: Report back to the user
-      server_path[0]=$(grep "${python_domain:-file}" $episode_file | $([[ -n ${selected_domain:-} ]] && echo "grep $selected_domain" || echo "grep '.*'") |\
-                       sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' $([[ -n $python_domain ]] && echo "-e s_.*file=\(.*\)_\1_")   |\
-                       eval $BROWSER_READABLE | grep -v 'itemprop' | sed -n '1 s/.*/&/p')
+      server_path[0]=$(egrep "${python_domain:-file}|${selected_domain:-}" $episode_file   |\
+                       sed -e 's_.*src="\(.*\)"_\1_' -e 's_".*__' -e 's_>__' -e 's_<.*>__g' \
+                       $([[ -n $python_domain ]] && echo "-e s_.*file=\(.*\)_\1_") | eval $BROWSER_READABLE |\
+                       grep -v 'itemprop' | egrep 'file|embed' | sed -n '1 p' | sed 's/%26videoAutoPlay=0//')
 
       [[ -z ${server_path[0]:-} ]] &&
       {
