@@ -39,7 +39,7 @@ trap 'Early_Termination' SIGHUP SIGINT SIGTERM
 # The name of this program is ...
 #-PROGNAME=$(basename $0 | sed 's_.*_GNU\ \u&_')
 readonly PROGNAME=Genshiken
-readonly VERSION=0.5.1
+readonly VERSION=0.5.2
 
 # Dependency 1: GNU Bash 4+ (There are certain features that I use that only exist in bash 4 and up)
 [[ $BASH_VERSINFO -lt 4 ]] && { echo "[${FUNCNAME[0]}] You need to be running version 4+ of GNU Bash in order to run this script.  Sorry!" >&2; exit 3; }
@@ -280,7 +280,7 @@ do case "$1" in
       echo -e "\t-f, --no-update\t\t\tSkips the Extract_Series_List procedure that creates an Anime-List, and proceeds to using your last downloaded copy"
       echo -e "\t--no-sessions\t\t\tPrevents ${PROGNAME} from creating/restoring previous session files (check the man page for more information)"
       echo -e "\t-p, --no-pager\t\t\tSends output that would normally go to a pager, to standard output instead"
-      echo -e "\t--limited-bandwidth\t\tRestarts network connections whenever their are network time-outs, through the use of wget and mplayer"
+      echo -e "\t--limited-bandwidth\t\tRestarts network connections whenever there are network time-outs, through the use of wget and mplayer"
       echo -e "\t--rgb=type, --colorize=type\tAdds color during a ${PROGNAME,?} session.  A value of \"dark\" provides subtle colors; of \"light\", bold colors"
       echo -e "\t-v, --commands\t\t\tOutput ${PROGNAME}'s command expansions to standard output, and to \"$TMPDIR/${PROGNAME,?}-$USER/debug.log\""
       echo -e "\t--verbose=[seconds]\t\tSimilar to \"--commands\", except a debug prompt is added and an optional value delays the prompt by \"seconds\""
